import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { BulkCreateDraftPostsOptions, BulkCreateDraftPostsResponse, BulkDeleteDraftPostsOptions, BulkDeleteDraftPostsResponse, BulkUpdateDraftPostsOptions, BulkUpdateDraftPostsResponse, CreateDraftPostOptions, CreateDraftPostResponse, DeleteDraftPostOptions, DraftCreatedEnvelope, DraftDeletedEnvelope, DraftPost, DraftPostsQueryBuilder, DraftUpdatedEnvelope, GetDeletedDraftPostResponse, GetDraftPostOptions, GetDraftPostResponse, ListDeletedDraftPostsOptions, ListDeletedDraftPostsResponse, ListDraftPostsOptions, ListDraftPostsResponse, PublishDraftPostResponse, QueryDraftPostsOptions, RestoreFromTrashBinResponse, UpdateDraftPost, UpdateDraftPostOptions, UpdateDraftPostResponse } from './blog-v3-draft-draft-posts.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function createDraftPost(httpClient: HttpClient): CreateDraftPostSignature;
interface CreateDraftPostSignature {
    /**
     * Creates a draft post.
     *
     * For 3rd-party apps, `memberId` is a required field.
     *
     * In `categoryIds`, only categories that already exist will be added to the draft post. Including
     * `categoryIds` that do not exist will not return an error, but they will not be added to the `categoryIds` array.
     * If some of the categories exist, those will be added while those that do not exist will not be added to `categoryIds`.
     * You can check which categories are available with
     * List Categories ([SDK](https://dev.wix.com/docs/sdk/backend-modules/blog/categories/list-categories) | [REST](https://dev.wix.com/docs/rest/business-solutions/blog/category/list-categories)).
     * @param - Draft post to create.
     * @param - Options for creating a draft post.
     */
    (draftPost: DraftPost, options?: CreateDraftPostOptions | undefined): Promise<CreateDraftPostResponse>;
}
export declare function bulkCreateDraftPosts(httpClient: HttpClient): BulkCreateDraftPostsSignature;
interface BulkCreateDraftPostsSignature {
    /**
     * Creates multiple draft posts.
     * @param - Draft posts to create.
     * @param - Options for creating multiple draft posts.
     */
    (draftPosts: DraftPost[], options?: BulkCreateDraftPostsOptions | undefined): Promise<BulkCreateDraftPostsResponse>;
}
export declare function bulkUpdateDraftPosts(httpClient: HttpClient): BulkUpdateDraftPostsSignature;
interface BulkUpdateDraftPostsSignature {
    /**
     * Updates multiple draft posts.
     * @param - Options for updating multiple draft posts.
     */
    (options?: BulkUpdateDraftPostsOptions | undefined): Promise<BulkUpdateDraftPostsResponse>;
}
export declare function listDeletedDraftPosts(httpClient: HttpClient): ListDeletedDraftPostsSignature;
interface ListDeletedDraftPostsSignature {
    /**
     * Retrieves a list of up to 100 deleted draft posts.
     *
     * List Draft Posts runs with these defaults, which you can override:
     * - `editedDate` is sorted in descending order. In this case,`editedDate` implies the date the post was deleted.
     * - `paging.limit` is `50`.
     * - `paging.offset` is `0`.
     * @param - Options for listing deleted draft posts.
     */
    (options?: ListDeletedDraftPostsOptions | undefined): Promise<ListDeletedDraftPostsResponse>;
}
export declare function getDraftPost(httpClient: HttpClient): GetDraftPostSignature;
interface GetDraftPostSignature {
    /**
     * Retrieves a draft post by the provided ID.
     * @param - Draft post ID.
     * @param - Options for getting a draft post.
     */
    (draftPostId: string, options?: GetDraftPostOptions | undefined): Promise<GetDraftPostResponse>;
}
export declare function updateDraftPost(httpClient: HttpClient): UpdateDraftPostSignature;
interface UpdateDraftPostSignature {
    /**
     * Updates a draft post.
     * @param - Draft post ID.
     * @param - Options for updating a draft post.
     * @param - Draft Post info.
     */
    (_id: string, draftPost: UpdateDraftPost, options?: UpdateDraftPostOptions | undefined): Promise<UpdateDraftPostResponse>;
}
export declare function deleteDraftPost(httpClient: HttpClient): DeleteDraftPostSignature;
interface DeleteDraftPostSignature {
    /**
     * Moves a draft post to the trash bin.
     * A published post can also be deleted by the `post.id`. See the Posts API ([SDK](https://dev.wix.com/docs/sdk/backend-modules/blog/posts/) | [REST](https://dev.wix.com/docs/rest/business-solutions/blog/posts-stats/post-object)) for more information about posts.
     *
     * To permanently delete a post bypassing the trash bin, set the `permanent` field value to `true`. The post can't be restored after this.
     * @param - Draft post ID.
     * @param - Options for deleting a draft post.
     */
    (draftPostId: string, options?: DeleteDraftPostOptions | undefined): Promise<void>;
}
export declare function removeFromTrashBin(httpClient: HttpClient): RemoveFromTrashBinSignature;
interface RemoveFromTrashBinSignature {
    /**
     * Permanently deletes a draft post that is currently in the trash bin.
     *
     * This action is permanent and can't be reversed.
     * @param - Draft post ID.
     */
    (draftPostId: string): Promise<void>;
}
export declare function bulkDeleteDraftPosts(httpClient: HttpClient): BulkDeleteDraftPostsSignature;
interface BulkDeleteDraftPostsSignature {
    /**
     * Deletes multiple draft posts.
     * @param - Post IDs.
     * @param - Options for deleting multiple draft posts.
     */
    (postIds: string[], options?: BulkDeleteDraftPostsOptions | undefined): Promise<BulkDeleteDraftPostsResponse>;
}
export declare function listDraftPosts(httpClient: HttpClient): ListDraftPostsSignature;
interface ListDraftPostsSignature {
    /**
     * Retrieves a list of up to 100 draft posts per request.
     *
     * List Draft Posts runs with these defaults, which you can override:
     * - `editedDate` is sorted in descending order.
     * - `paging.limit` is `50`.
     * - `paging.offset` is `0`.
     * @param - Options for listing multiple draft posts.
     */
    (options?: ListDraftPostsOptions | undefined): Promise<ListDraftPostsResponse>;
}
export declare function getDeletedDraftPost(httpClient: HttpClient): GetDeletedDraftPostSignature;
interface GetDeletedDraftPostSignature {
    /**
     * Retrieves a deleted draft post from the trash bin by the provided ID.
     * @param - Draft post ID.
     */
    (draftPostId: string): Promise<GetDeletedDraftPostResponse>;
}
export declare function restoreFromTrashBin(httpClient: HttpClient): RestoreFromTrashBinSignature;
interface RestoreFromTrashBinSignature {
    /**
     * Restores a deleted draft post from the trash bin by the provided ID.
     * @param - Draft post ID.
     */
    (draftPostId: string): Promise<RestoreFromTrashBinResponse>;
}
export declare function queryDraftPosts(httpClient: HttpClient): QueryDraftPostsSignature;
interface QueryDraftPostsSignature {
    /**
     * Creates a query to retrieve a list of up to 100 draft posts.
     *
     *
     * The `queryDraftPosts()` function builds a query to retrieve a list of up to 100 draft posts, and returns a `DraftPostsQueryBuilder` object.
     *
     * The returned object contains the query definition, which is typically used to run the query using the `find()` function.
     *
     * You can refine the query by chaining `DraftPostsQueryBuilder` functions onto the query. `DraftPostsQueryBuilder` functions enable you to sort, filter, and control the results that `queryDraftPosts()` returns.
     *
     * `queryDraftPosts()` runs with these `DraftPostsQueryBuilder` defaults that can be overridden:
     * - `limit(50)`
     * - `ascending('_id')`
     *
     * The following `DraftPostsQueryBuilder` functions are supported for `queryDraftPosts()`. For a full description of the Draft Posts object, see the object returned for the `items` property in `DraftPostsQueryResult`.
     * @param - Options for querying draft posts.
     */
    (options?: QueryDraftPostsOptions | undefined): DraftPostsQueryBuilder;
}
export declare function publishDraftPost(httpClient: HttpClient): PublishDraftPostSignature;
interface PublishDraftPostSignature {
    /**
     * Publishes a draft post by ID. This creates a new post ([SDK](https://dev.wix.com/docs/sdk/backend-modules/blog/posts/) | [REST](https://dev.wix.com/docs/rest/business-solutions/blog/posts-stats/post-object))
     * with the data from the draft post.
     *
     * If the draft post was already published, the published post will be updated with the latest values
     * from the draft post.
     * @param - Draft post ID.
     */
    (draftPostId: string): Promise<PublishDraftPostResponse>;
}
export declare const onDraftCreated: EventDefinition<DraftCreatedEnvelope, "wix.blog.v3.draft_created">;
export declare const onDraftDeleted: EventDefinition<DraftDeletedEnvelope, "wix.blog.v3.draft_deleted">;
export declare const onDraftUpdated: EventDefinition<DraftUpdatedEnvelope, "wix.blog.v3.draft_updated">;
export { Action, ActionEvent, Alignment, AnchorData, AppEmbedData, AppEmbedDataAppDataOneOf, AppType, ApplicationError, ApproveDraftPostRequest, ApproveDraftPostResponse, AudioData, Background, BackgroundBackgroundOneOf, BackgroundType, BaseEventMetadata, BlockquoteData, BlogPaging, BookingData, Border, BorderColors, BulkActionMetadata, BulkCreateDraftPostsOptions, BulkCreateDraftPostsRequest, BulkCreateDraftPostsResponse, BulkDeleteDraftPostsOptions, BulkDeleteDraftPostsRequest, BulkDeleteDraftPostsResponse, BulkDraftPostResult, BulkRejectDraftPostRequest, BulkRejectDraftPostResponse, BulkRevertToUnpublishedRequest, BulkRevertToUnpublishedResponse, BulkUpdateDraftPostLanguageRequest, BulkUpdateDraftPostLanguageResponse, BulkUpdateDraftPostsOptions, BulkUpdateDraftPostsRequest, BulkUpdateDraftPostsResponse, BulletedListData, ButtonData, ButtonDataType, CaptionData, Category, CategoryTranslation, CellStyle, CodeBlockData, CollapsibleListData, ColorData, Colors, CoverMedia, CoverMediaMediaOneOf, CreateDraftPostOptions, CreateDraftPostRequest, CreateDraftPostResponse, Crop, CursorPaging, Cursors, Decoration, DecorationDataOneOf, DecorationType, DeleteDraftPostOptions, DeleteDraftPostRequest, DeleteDraftPostResponse, Design, Dimensions, Direction, DividerData, DocumentStyle, DomainEvent, DomainEventBodyOneOf, DraftCategoriesUpdated, DraftCreatedEnvelope, DraftDeletedEnvelope, DraftPost, DraftPostOwnerChanged, DraftPostTranslation, DraftPostsQueryBuilder, DraftPostsQueryResult, DraftTagsUpdated, DraftUpdatedEnvelope, EmbedData, EmbedMedia, EmbedThumbnail, EmbedVideo, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventData, EventMetadata, Field, FileData, FileSource, FileSourceDataOneOf, FocalPoint, FontSizeData, FontType, GIF, GIFData, GIFType, GalleryData, GalleryOptions, GetDeletedDraftPostRequest, GetDeletedDraftPostResponse, GetDraftPostOptions, GetDraftPostRequest, GetDraftPostResponse, GetDraftPostTotalsRequest, GetDraftPostTotalsResponse, GetDraftPostsSort, GetPostAmountsByLanguageRequest, GetPostAmountsByLanguageResponse, Gradient, HTMLData, HTMLDataDataOneOf, HeadingData, Height, IdentificationData, IdentificationDataIdOneOf, Image, ImageData, ImageDataStyles, InitialDraftPostsCopied, InitialExpandedItems, IsDraftPostAutoTranslatableRequest, IsDraftPostAutoTranslatableResponse, Item, ItemDataOneOf, ItemMetadata, ItemStyle, Keyword, Layout, LayoutCellData, LayoutType, LineStyle, Link, LinkData, LinkDataOneOf, LinkPreviewData, LinkPreviewDataStyles, ListDeletedDraftPostsOptions, ListDeletedDraftPostsRequest, ListDeletedDraftPostsResponse, ListDraftPostsOptions, ListDraftPostsRequest, ListDraftPostsResponse, ListValue, MapData, MapSettings, MapType, MarkPostAsInModerationRequest, MarkPostAsInModerationResponse, MaskedDraftPosts, Media, MediaMediaOneOf, MentionData, MessageEnvelope, MetaData, Metadata, ModerationDetails, ModerationStatusStatus, Node, NodeDataOneOf, NodeStyle, NodeType, NullValue, Oembed, Option, OptionDesign, OptionLayout, OrderedListData, Orientation, Origin, PDFSettings, Paging, PagingMetadataV2, ParagraphData, Permissions, PlatformQuery, PlatformQueryPagingMethodOneOf, PlaybackOptions, PluginContainerData, PluginContainerDataAlignment, PluginContainerDataWidth, PluginContainerDataWidthDataOneOf, Poll, PollData, PollDataLayout, PollDesign, PollLayout, PollLayoutDirection, PollLayoutType, PollSettings, Position, PostAmountByLanguage, PublishDraftPostRequest, PublishDraftPostResponse, QueryDraftPostsOptions, QueryDraftPostsRequest, QueryDraftPostsResponse, RejectDraftPostRequest, RejectDraftPostResponse, Rel, RemoveFromTrashBinRequest, RemoveFromTrashBinResponse, RestoreFromTrashBinRequest, RestoreFromTrashBinResponse, RestoreInfo, RevertToUnpublishedRequest, RevertToUnpublishedResponse, RichContent, SeoSchema, Settings, SortOrder, Sorting, Source, Spoiler, SpoilerData, Status, Styles, StylesBorder, TableCellData, TableData, Tag, Target, TextAlignment, TextData, TextNodeStyle, TextStyle, Thumbnails, ThumbnailsAlignment, TotalDraftPosts, TotalDraftPostsGroupingField, TranslateCategoryRequest, TranslateCategoryResponse, TranslateDraftRequest, TranslateDraftResponse, Type, UnpublishPostRequest, UnpublishPostResponse, UpdateDraftPost, UpdateDraftPostContentRequest, UpdateDraftPostContentRequestDraftContentOneOf, UpdateDraftPostContentResponse, UpdateDraftPostLanguageRequest, UpdateDraftPostLanguageResponse, UpdateDraftPostOptions, UpdateDraftPostRequest, UpdateDraftPostResponse, V1Media, VerticalAlignment, Video, VideoData, VideoResolution, ViewMode, ViewRole, VoteRole, WebhookIdentityType, Width, WidthType, WixMedia, } from './blog-v3-draft-draft-posts.universal.js';
