import { RequestOptionsFactory } from '@wix/sdk-types';
/**
 * Creates a draft post.
 *
 * For 3rd-party apps, `memberId` is a required field.
 *
 * In `categoryIds`, only categories that already exist will be added to the draft post. Including
 * `categoryIds` that do not exist will not return an error, but they will not be added to the `categoryIds` array.
 * If some of the categories exist, those will be added while those that do not exist will not be added to `categoryIds`.
 * You can check which categories are available with
 * List Categories ([SDK](https://dev.wix.com/docs/sdk/backend-modules/blog/categories/list-categories) | [REST](https://dev.wix.com/docs/rest/business-solutions/blog/category/list-categories)).
 */
export declare function createDraftPost(payload: object): RequestOptionsFactory<any>;
/** Creates multiple draft posts. */
export declare function bulkCreateDraftPosts(payload: object): RequestOptionsFactory<any>;
/** Updates multiple draft posts. */
export declare function bulkUpdateDraftPosts(payload: object): RequestOptionsFactory<any>;
/**
 * Retrieves a list of up to 100 deleted draft posts.
 *
 * List Draft Posts runs with these defaults, which you can override:
 * - `editedDate` is sorted in descending order. In this case,`editedDate` implies the date the post was deleted.
 * - `paging.limit` is `50`.
 * - `paging.offset` is `0`.
 */
export declare function listDeletedDraftPosts(payload: object): RequestOptionsFactory<any>;
/** Retrieves a draft post by the provided ID. */
export declare function getDraftPost(payload: object): RequestOptionsFactory<any>;
/** Updates a draft post. */
export declare function updateDraftPost(payload: object): RequestOptionsFactory<any>;
/**
 * Moves a draft post to the trash bin.
 * A published post can also be deleted by the `post.id`. See the Posts API ([SDK](https://dev.wix.com/docs/sdk/backend-modules/blog/posts/) | [REST](https://dev.wix.com/docs/rest/business-solutions/blog/posts-stats/post-object)) for more information about posts.
 *
 * To permanently delete a post bypassing the trash bin, set the `permanent` field value to `true`. The post can't be restored after this.
 */
export declare function deleteDraftPost(payload: object): RequestOptionsFactory<any>;
/**
 * Permanently deletes a draft post that is currently in the trash bin.
 *
 * This action is permanent and can't be reversed.
 */
export declare function removeFromTrashBin(payload: object): RequestOptionsFactory<any>;
/** Deletes multiple draft posts. */
export declare function bulkDeleteDraftPosts(payload: object): RequestOptionsFactory<any>;
/**
 * Retrieves a list of up to 100 draft posts per request.
 *
 * List Draft Posts runs with these defaults, which you can override:
 * - `editedDate` is sorted in descending order.
 * - `paging.limit` is `50`.
 * - `paging.offset` is `0`.
 */
export declare function listDraftPosts(payload: object): RequestOptionsFactory<any>;
/** Retrieves a deleted draft post from the trash bin by the provided ID. */
export declare function getDeletedDraftPost(payload: object): RequestOptionsFactory<any>;
/** Restores a deleted draft post from the trash bin by the provided ID. */
export declare function restoreFromTrashBin(payload: object): RequestOptionsFactory<any>;
/**
 * Creates a query to retrieve a list of up to 100 draft posts.
 *
 *
 * The `queryDraftPosts()` function builds a query to retrieve a list of up to 100 draft posts, and returns a `DraftPostsQueryBuilder` object.
 *
 * The returned object contains the query definition, which is typically used to run the query using the `find()` function.
 *
 * You can refine the query by chaining `DraftPostsQueryBuilder` functions onto the query. `DraftPostsQueryBuilder` functions enable you to sort, filter, and control the results that `queryDraftPosts()` returns.
 *
 * `queryDraftPosts()` runs with these `DraftPostsQueryBuilder` defaults that can be overridden:
 * - `limit(50)`
 * - `ascending('_id')`
 *
 * The following `DraftPostsQueryBuilder` functions are supported for `queryDraftPosts()`. For a full description of the Draft Posts object, see the object returned for the `items` property in `DraftPostsQueryResult`.
 */
export declare function queryDraftPosts(payload: object): RequestOptionsFactory<any>;
/**
 * Publishes a draft post by ID. This creates a new post ([SDK](https://dev.wix.com/docs/sdk/backend-modules/blog/posts/) | [REST](https://dev.wix.com/docs/rest/business-solutions/blog/posts-stats/post-object))
 * with the data from the draft post.
 *
 * If the draft post was already published, the published post will be updated with the latest values
 * from the draft post.
 */
export declare function publishDraftPost(payload: object): RequestOptionsFactory<any>;
